pub fn start(config: SessionConfig, request: WebSearchRequest) -> WebSearchRunExpand description
Starts one Session run and adapts its events on the current Tokio runtime.
pub fn start(config: SessionConfig, request: WebSearchRequest) -> WebSearchRunStarts one Session run and adapts its events on the current Tokio runtime.